=========
bodhi-sar
=========

Synopsis
========

``bodhi-sar`` [OPTIONS]


Description
===========

``bodhi-sar`` is used to print out GDPR Subject Access Request (SAR) data for a FAS account.


Options
=======

``--help``

    Show help text and exit.

``--username TEXT``

    The username for which SAR data should be gathered. This can also be set with
    the ``SAR_USERNAME`` environment variable.

``--human-readable``

    Print user data in human readable format. The script defaults to JSON output.

``--version``

    Show version and exit.


Help
====

If you find bugs in Bodhi (or in this man page), please feel free to file a bug report or a pull
request::

    https://github.com/fedora-infra/bodhi

Bodhi's documentation is available online: https://bodhi.fedoraproject.org/docs
